summaryrefslogtreecommitdiffstats
path: root/textw
diff options
context:
space:
mode:
authorMike Fulbright <msf@redhat.com>2001-01-23 21:35:07 +0000
committerMike Fulbright <msf@redhat.com>2001-01-23 21:35:07 +0000
commit9391b848bea6b9072b3343dbefc63a2515442201 (patch)
tree260a56e7d380cb27c6d23e2dc9b15b0d954a79ee /textw
parentefd917a7fb2596f375d9aea78599bb8b89dfeb11 (diff)
downloadanaconda-9391b848bea6b9072b3343dbefc63a2515442201.tar.gz
anaconda-9391b848bea6b9072b3343dbefc63a2515442201.tar.xz
anaconda-9391b848bea6b9072b3343dbefc63a2515442201.zip
make lba32 warning a dialog under GUI install, and fix off by one bug with endpoint (should be 1024, not 1023)
Diffstat (limited to 'textw')
-rw-r--r--textw/partitioning_text.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/textw/partitioning_text.py b/textw/partitioning_text.py
index 92ba573e4..56e85aef5 100644
--- a/textw/partitioning_text.py
+++ b/textw/partitioning_text.py
@@ -357,17 +357,17 @@ class LBA32WarningWindow:
if dir == -1:
return INSTALL_NOOP
# check if boot partition is above 1023 cyl limit
if iutil.getArch() != "i386":
return INSTALL_NOOP
maxcyl = todo.fstab.getBootPartitionMaxCylFromDesired()
log("Maximum cylinder is %s" % maxcyl)
- if maxcyl > 1023:
+ if maxcyl > 1024:
if not todo.fstab.edd:
rc = ButtonChoiceWindow(screen, _("Boot Partition Warning"),
_("You have put the partition containing the kernel (the "
- "boot partition) above the 1023 cylinder limit, and "
+ "boot partition) above the 1024 cylinder limit, and "
"it appears that this systems BIOS does not support "
"booting from above this limit. Proceeding will "
"most likely make the system unable to reboot into "
@@ -387,7 +387,7 @@ class LBA32WarningWindow:
else:
rc = ButtonChoiceWindow(screen, _("Boot Partition Warning"),
_("You have put the partition containing the kernel (the "
- "boot partition) above the 1023 cylinder limit. "
+ "boot partition) above the 1024 cylinder limit. "
"It appears that this systems BIOS supports "
"booting from above this limit. \n\n"
"It is HIGHLY recommended you make a boot floppy when "
@@ -357,17 +357,17 @@ class LBA32WarningWindow:
if dir == -1:
return INSTALL_NOOP
- # check if boot partition is above 1023 cyl limit
+ # check if boot partition is above 1024 cyl limit
if iutil.getArch() != "i386":
return INSTALL_NOOP